TypeAheadFormField<T> class

A FormField implementation of TypeAheadField, that allows the value to be saved, validated, etc.

See also:

Inheritance

Constructors

TypeAheadFormField({Key? key, String? initialValue, bool getImmediateSuggestions = false, @Deprecated('Use autovalidateMode parameter which provides more specific ' 'behavior related to auto validation. ' 'This feature was deprecated after Flutter v1.19.0.') bool autovalidate = false, bool enabled = true, AutovalidateMode autovalidateMode = AutovalidateMode.disabled, FormFieldSetter<String>? onSaved, FormFieldValidator<String>? validator, ErrorBuilder? errorBuilder, WidgetBuilder? noItemsFoundBuilder, WidgetBuilder? loadingBuilder, Duration debounceDuration = const Duration(milliseconds: 300), SuggestionsBoxDecoration suggestionsBoxDecoration = const SuggestionsBoxDecoration(), SuggestionsBoxController? suggestionsBoxController, required SuggestionSelectionCallback<T> onSuggestionSelected, required ItemBuilder<T> itemBuilder, required SuggestionsCallback<T> suggestionsCallback, double suggestionsBoxVerticalOffset = 5.0, TextFieldConfiguration textFieldConfiguration = const TextFieldConfiguration(), AnimationTransitionBuilder? transitionBuilder, Duration animationDuration = const Duration(milliseconds: 500), double animationStart = 0.25, AxisDirection direction = AxisDirection.down, bool hideOnLoading = false, bool hideOnEmpty = false, bool hideOnError = false, bool hideSuggestionsOnKeyboardHide = true, bool keepSuggestionsOnLoading = true, bool keepSuggestionsOnSuggestionSelected = false, bool autoFlipDirection = false, bool hideKeyboard = false})
Creates a TypeAheadFormField

Properties

autovalidateMode → AutovalidateMode
Used to enable/disable this form field auto validation and update its error text.
finalinherited
builder → FormFieldBuilder<String>
Function that returns the widget representing this form field.
finalinherited
enabled → bool
Whether the form is able to receive user input.
finalinherited
errorBuilder → FormFieldErrorBuilder?
Function that returns the widget representing the error to display.
finalinherited
forceErrorText → String?
An optional property that forces the FormFieldState into an error state by directly setting the FormFieldState.errorText property without running the validator function.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
initialValue → String?
An optional value to initialize the form field to, or null otherwise.
finalinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onReset → VoidCallback?
An optional method to call when the form field is reset via FormFieldState.reset.
finalinherited
onSaved → FormFieldSetter<String>?
An optional method to call with the final value when the form is saved via FormState.save.
finalinherited
restorationId → String?
Restoration ID to save and restore the state of the form field.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textFieldConfiguration → TextFieldConfiguration
The configuration of the TextField that the TypeAhead widget displays
final
validator → FormFieldValidator<String>?
An optional method that validates an input. Returns an error string to display if the input is invalid, or null otherwise.
finalinherited

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _TypeAheadFormFieldState<T>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited